import { createElement as createElement$1 } from 'react';
import '../Provider/ThemeContext.js';
import 'classnames';
import 'emotion';
import '@emotion/core';
import 'emotion-theming';
import '@emotion/styled';
import '../utils/useTheme.js';
import { _ as _objectSpread2, c as _extends, d as _objectWithoutPropertiesLoose } from '../chunk-0c448560.js';
import 'lodash/kebabCase';
import 'tinycolor2';
import '../utils/isFunction.js';
import '../utils/get.js';
import '../utils/theme.js';
import '../utils/omit.js';
import '../utils/pick.js';
import { pickCSSProps, omitCSSProps } from '../utils/cssProps.js';
import '../utils/useLocalStorage.js';
import '../Provider/ColorModeContext.js';
import '../utils/useColorMode.js';
import '../utils/useStyle.js';
import '../utils/omitBy.js';
import '../utils/useDefaultProps.js';
import '../utils/useDebounce.js';
import 'lodash/uniq';
import { useClassName } from '../utils/useClassName.js';
import '../utils/useBreakpoint.js';
import '../utils/uniqueId.js';
import '../utils/times.js';
import '../utils/parseIcons.js';
import '../utils/colors.js';
import '../utils/palette.js';
import '../utils/mergeRefs.js';
import 'deepmerge';
import 'lodash/set';
import '../utils/applyTheme.js';
import '../utils/bindFns.js';
import { createComponent } from '../utils/createComponent.js';
import { createElement } from '../utils/createElement.js';
import { createHook } from '../utils/createHook.js';
import '../utils/forwardRefWithUse.js';
import '../utils/fieldAdaptors.js';
import '@emotion/is-prop-valid';
import '../utils/htmlProps.js';
import '../utils/OutsideClickHandler.js';
import '../theme/palette.js';
import { Box } from 'reakit';
import '../Button/styles-d451730b.js';
import ConditionalWrap from 'conditional-wrap';
import '../Box/styles-579aeb3a.js';
import { Box as Box$1 } from '../Box/Box.js';
import '../Flex/styles-e3ee5bb0.js';
import '../Flex/Flex.js';
import '../Icon/styles-f429b8b4.js';
import { Icon } from '../Icon/Icon.js';
import '../Text/styles-58fa853a.js';
import '../Text/Text.js';
import '../Spinner/styles-25413c76.js';
import { Spinner } from '../Spinner/Spinner.js';
import '../Button/Button.js';
import 'reakit/VisuallyHidden';
import '../Button/ButtonClose.js';
import '../Button/index.js';
import { b as InputIcon$1, I as InputWrapper, c as InputSpinner, a as Input$1, d as InputField$1 } from './styles-7f6a0be6.js';
import InputMask from 'react-input-mask';
import '../FieldWrapper/styles-084615ad.js';
import '../Card/styles-1666ffe3.js';
import '../Card/Card.js';
import '../Card/index.js';
import '../Disclosure/styles-33b2b9d5.js';
import '../Disclosure/DisclosureState.js';
import '../Disclosure/Disclosure.js';
import '../Disclosure/DisclosureContent.js';
import '../Disclosure/index.js';
import '../Label/styles-68063bea.js';
import '../Label/Label.js';
import { FieldWrapper } from '../FieldWrapper/FieldWrapper.js';
import '../Group/styles-75b5e767.js';
import { Group } from '../Group/Group.js';

var useProps = createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var before = props.before,
      after = props.after,
      inputRef = props.inputRef,
      isLoading = props.isLoading,
      isRequired = props.isRequired,
      state = props.state,
      restProps = _objectWithoutPropertiesLoose(props, ["before", "after", "inputRef", "isLoading", "isRequired", "state"]);

  var wrapperClassName = useClassName({
    style: InputWrapper,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Wrapper',
    prevClassName: restProps.className
  });
  var spinnerClassName = useClassName({
    style: InputSpinner,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Spinner'
  });
  var boxProps = Box$1.useProps(_objectSpread2(_objectSpread2({}, omitCSSProps(restProps)), {}, {
    className: undefined,
    elementRef: inputRef || props.elementRef,
    wrapElement: function wrapElement(children) {
      return /*#__PURE__*/createElement$1(Box$1, _extends({
        className: wrapperClassName
      }, pickCSSProps(props)), before && /*#__PURE__*/createElement$1(Box$1, {
        display: "inline-flex",
        position: "absolute",
        zIndex: "3",
        height: "100%"
      }, before), after && /*#__PURE__*/createElement$1(Box$1, {
        display: "inline-flex",
        position: "absolute",
        right: "0",
        zIndex: "3",
        height: "100%"
      }, after), children, isLoading && /*#__PURE__*/createElement$1(Spinner, {
        className: spinnerClassName,
        color: "text"
      }));
    }
  }));
  var className = useClassName({
    style: Input$1,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return _objectSpread2(_objectSpread2({}, boxProps), {}, {
    className: className,
    'aria-invalid': state === 'danger',
    'aria-required': isRequired
  });
}, {
  defaultProps: {
    type: 'text'
  },
  themeKey: 'Input'
});
var Input = createComponent(function (props) {
  var inputProps = useProps(props);
  var use = props.use;

  if (props.mask) {
    use = InputMask;
  }

  return createElement({
    children: props.children,
    component: Box,
    use: use,
    htmlProps: _objectSpread2(_objectSpread2({}, inputProps), props.mask ? {
      mask: props.mask
    } : {})
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Input'
  },
  defaultProps: {
    use: 'input'
  },
  themeKey: 'Input'
}); ////////////////////////////////////////////////////////////////

function InputIcon(props) {
  var className = useClassName({
    style: InputIcon$1,
    styleProps: props,
    themeKey: 'Input.Icon',
    prevClassName: props.className
  });
  return /*#__PURE__*/createElement$1(Icon, _extends({}, props, {
    className: className
  }));
} ////////////////////////////////////////////////////////////////

var useInputFieldProps = createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var addonAfter = props.addonAfter,
      addonBefore = props.addonBefore,
      children = props.children,
      after = props.after,
      autoComplete = props.autoComplete,
      autoFocus = props.autoFocus,
      before = props.before,
      defaultValue = props.defaultValue,
      description = props.description,
      disabled = props.disabled,
      hint = props.hint,
      inputRef = props.inputRef,
      inputProps = props.inputProps,
      isLoading = props.isLoading,
      isOptional = props.isOptional,
      isRequired = props.isRequired,
      orientation = props.orientation,
      label = props.label,
      name = props.name,
      size = props.size,
      mask = props.mask,
      max = props.max,
      maxLength = props.maxLength,
      min = props.min,
      minLength = props.minLength,
      multiple = props.multiple,
      pattern = props.pattern,
      placeholder = props.placeholder,
      readOnly = props.readOnly,
      spellCheck = props.spellCheck,
      step = props.step,
      state = props.state,
      tooltip = props.tooltip,
      tooltipTriggerComponent = props.tooltipTriggerComponent,
      type = props.type,
      value = props.value,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      overrides = props.overrides,
      validationText = props.validationText,
      restProps = _objectWithoutPropertiesLoose(props, ["addonAfter", "addonBefore", "children", "after", "autoComplete", "autoFocus", "before", "defaultValue", "description", "disabled", "hint", "inputRef", "inputProps", "isLoading", "isOptional", "isRequired", "orientation", "label", "name", "size", "mask", "max", "maxLength", "min", "minLength", "multiple", "pattern", "placeholder", "readOnly", "spellCheck", "step", "state", "tooltip", "tooltipTriggerComponent", "type", "value", "onBlur", "onChange", "onFocus", "overrides", "validationText"]);

  var boxProps = Box$1.useProps(restProps);
  var className = useClassName({
    style: InputField$1,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return _objectSpread2(_objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/createElement$1(FieldWrapper, {
      description: description,
      hint: hint,
      isOptional: isOptional,
      isRequired: isRequired,
      label: label,
      overrides: overrides,
      state: state,
      tooltip: tooltip,
      tooltipTriggerComponent: tooltipTriggerComponent,
      validationText: validationText
    }, function (_ref3) {
      var elementProps = _ref3.elementProps;
      return /*#__PURE__*/createElement$1(ConditionalWrap, {
        condition: addonBefore || addonAfter,
        wrap: function wrap(children) {
          return /*#__PURE__*/createElement$1(Group, {
            orientation: orientation,
            overrides: overrides
          }, children);
        }
      }, addonBefore, /*#__PURE__*/createElement$1(Input, _extends({
        after: after,
        autoComplete: autoComplete,
        autoFocus: autoFocus,
        before: before,
        defaultValue: defaultValue,
        disabled: disabled,
        inputRef: inputRef,
        isLoading: isLoading,
        isRequired: isRequired,
        name: name,
        size: size,
        mask: mask,
        max: max,
        maxLength: maxLength,
        min: min,
        minLength: minLength,
        multiple: multiple,
        pattern: pattern,
        placeholder: placeholder,
        readOnly: readOnly,
        spellCheck: spellCheck,
        step: step,
        state: state,
        type: type,
        value: value,
        onBlur: onBlur,
        onChange: onChange,
        onFocus: onFocus,
        overrides: overrides
      }, elementProps, inputProps)), addonAfter);
    })
  });
}, {
  defaultProps: {
    orientation: 'horizontal'
  },
  themeKey: 'InputField'
});
var InputField = createComponent(function (props) {
  var inputFieldProps = useInputFieldProps(props);
  return createElement({
    children: props.children,
    component: Box,
    use: props.use,
    htmlProps: inputFieldProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'InputField'
  },
  themeKey: 'InputField'
});

export { Input, InputField, InputIcon };
