'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
var uniqueId = require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-ef2b3fee.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-f03a673b.js');
require('../Flex/Flex.js');
require('../Icon/styles-5971248c.js');
var Icon = require('../Icon/Icon.js');
require('../Text/styles-778c8fc7.js');
var Text = require('../Text/Text.js');
require('../Spinner/styles-154c4cbf.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
var index = require('../Button/index.js');
var styles = require('./styles-6efb7d2c.js');

var AlertContext = React.createContext({});
var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var accent = props.accent,
      countdown = props.countdown,
      closeButtonProps = props.closeButtonProps,
      closeButtonIconProps = props.closeButtonIconProps,
      hasIcon = props.hasIcon,
      iconProps = props.iconProps,
      isInline = props.isInline,
      onClickClose = props.onClickClose,
      overrides = props.overrides,
      showCloseButton = props.showCloseButton,
      title = props.title,
      type = props.type,
      variant = props.variant,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["accent", "countdown", "closeButtonProps", "closeButtonIconProps", "hasIcon", "iconProps", "isInline", "onClickClose", "overrides", "showCloseButton", "title", "type", "variant"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles.Alert,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var alertCloseButtonClassName = useClassName.useClassName({
    style: styles.AlertCloseButton,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'CloseButton'
  });
  var titleId = uniqueId.useUniqueId('alertTitle');
  var descriptionId = uniqueId.useUniqueId('alertDescription');
  var context = React.useMemo(function () {
    return __chunk_1._objectSpread2({
      descriptionId: descriptionId,
      themeKeyOverride: themeKeyOverride,
      titleId: titleId
    }, props);
  }, [descriptionId, props, themeKeyOverride, titleId]);
  var palette = 'default';

  if (variant === 'fill') {
    palette = type + "Inverted";
  }

  if (variant === 'tint') {
    palette = type;
  }

  var children = /*#__PURE__*/React.createElement(AlertContext.Provider, {
    value: context
  }, accent && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(AlertAccent, {
    overrides: overrides
  }), countdown ? /*#__PURE__*/React.createElement(AlertAccent, {
    overrides: overrides,
    isBackground: true
  }) : null), /*#__PURE__*/React.createElement(AlertWrapper, {
    overrides: overrides
  }, /*#__PURE__*/React.createElement(Box.Box, {
    alignItems: "center",
    display: "flex"
  }, hasIcon && /*#__PURE__*/React.createElement(AlertIcon, {
    overrides: overrides
  }), /*#__PURE__*/React.createElement(AlertContent, {
    overrides: overrides
  }, title && /*#__PURE__*/React.createElement(AlertTitle, {
    overrides: overrides
  }, title), /*#__PURE__*/React.createElement(AlertDescription, {
    overrides: overrides
  }, props.children))), showCloseButton && /*#__PURE__*/React.createElement(Box.Box, {
    display: "flex"
  }, /*#__PURE__*/React.createElement(index.Button.Close, __chunk_1._extends({
    className: alertCloseButtonClassName,
    onClick: onClickClose,
    palette: palette,
    iconProps: closeButtonIconProps
  }, closeButtonProps)))));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    'aria-describedby': props.children ? descriptionId : undefined,
    'aria-labelledby': props.title ? titleId : undefined,
    className: className,
    children: children,
    role: 'alert'
  });
}, {
  defaultProps: {
    accentSize: '4px',
    hasIcon: true,
    type: 'info',
    variant: 'shadowed'
  },
  themeKey: 'Alert'
});
var Alert = createComponent.createComponent(function (props) {
  var alertProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: alertProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Alert'
  },
  themeKey: 'Alert'
}); /////////////////////////////////////

function AlertIcon(props) {
  var iconProps = props.iconProps,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["iconProps"]);

  var context = React.useContext(AlertContext);
  var alertIconWrapperClassName = useClassName.useClassName({
    style: styles.AlertIconWrapper,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'IconWrapper'
  });
  var fontSize = '400';

  if (!context.title || context.isInline) {
    fontSize = '200';
  }

  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertIconWrapperClassName
  }, restProps), /*#__PURE__*/React.createElement(Icon.Icon, __chunk_1._extends({
    "aria-hidden": true,
    color: context.variant === 'fill' ? context.type + "Inverted" : context.type,
    fontSize: fontSize,
    icon: context.type
  }, iconProps)));
} /////////////////////////////////////

function AlertContent(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(AlertContext);
  var alertContentClassName = useClassName.useClassName({
    style: styles.AlertContent,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'Content'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertContentClassName
  }, restProps), children);
} /////////////////////////////////////

function AlertWrapper(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(AlertContext);
  var alertWrapperClassName = useClassName.useClassName({
    style: styles.AlertWrapper,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'Wrapper'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertWrapperClassName
  }, restProps), children);
} /////////////////////////////////////

function AlertAccent(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(AlertContext);
  var alertAccentClassName = useClassName.useClassName({
    style: styles.AlertAccent,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'Accent'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertAccentClassName
  }, restProps), children);
} /////////////////////////////////////

function AlertTitle(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(AlertContext);
  var alertTitleClassName = useClassName.useClassName({
    style: styles.AlertTitle,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'Title'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertTitleClassName
  }, restProps), /*#__PURE__*/React.createElement(Text.Text, {
    fontWeight: "semibold",
    id: context.titleId
  }, children));
} /////////////////////////////////////

function AlertDescription(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(AlertContext);
  var alertDescriptionClassName = useClassName.useClassName({
    style: styles.AlertDescription,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Alert',
    themeKeyOverride: context.themeKeyOverride,
    themeKeySuffix: 'Description'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: alertDescriptionClassName,
    id: context.descriptionId
  }, restProps), children);
}

exports.Alert = Alert;
exports.AlertAccent = AlertAccent;
exports.AlertContent = AlertContent;
exports.AlertContext = AlertContext;
exports.AlertDescription = AlertDescription;
exports.AlertIcon = AlertIcon;
exports.AlertTitle = AlertTitle;
exports.AlertWrapper = AlertWrapper;
