'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
var reakit = require('reakit');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Text/styles-778c8fc7.js');
var Text = require('../Text/Text.js');
var styles = require('./styles-edae2311.js');
require('../Link/styles-b8dd9778.js');
var Link = require('../Link/Link.js');
require('../List/styles-951c12b3.js');
require('../List/List.js');
require('../List/ListItem.js');
var index = require('../List/index.js');
require('../Navigation/styles-400246fe.js');
var Navigation = require('../Navigation/Navigation.js');

var BreadcrumbContext = React.createContext({});
var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var hasSeparator = props.hasSeparator,
      overrides = props.overrides,
      separator = props.separator,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["hasSeparator", "overrides", "separator"]);

  var navigationProps = Navigation.Navigation.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, restProps), {}, {
    overrides: overrides
  }));
  var className = useClassName.useClassName({
    style: styles.Breadcrumb,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: navigationProps.className
  });
  var context = React.useMemo(function () {
    return {
      overrides: props.overrides
    };
  }, [props.overrides]);
  var children = /*#__PURE__*/React.createElement(BreadcrumbContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement(index.List, {
    isOrdered: true,
    orientation: "horizontal",
    listStyleType: "none",
    overrides: overrides
  }, React.Children.map(props.children, function (child, index) {
    if (!React.isValidElement(child)) return child;
    var isLastChild = React.Children.count(props.children) - 1 === index;
    return React.cloneElement(child, __chunk_1._objectSpread2({
      hasSeparator: typeof hasSeparator !== 'undefined' ? hasSeparator : !isLastChild,
      separator: separator
    }, child.props));
  })));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, navigationProps), {}, {
    'aria-label': 'Breadcrumb',
    className: className,
    children: children
  });
}, {
  themeKey: 'Breadcrumb'
});
var Breadcrumb = createComponent.createComponent(function (props) {
  var breadcrumbProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: breadcrumbProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Breadcrumb'
  },
  defaultProps: {
    use: 'nav'
  },
  themeKey: 'Breadcrumb'
}); //////////////////////////////

var useBreadcrumbItemProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var hasSeparator = props.hasSeparator,
      isCurrent = props.isCurrent,
      overrides = props.overrides,
      separator = props.separator,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["hasSeparator", "isCurrent", "overrides", "separator"]);

  var boxProps = index.List.Item.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, restProps), {}, {
    overrides: overrides
  }));
  var contextProps = React.useContext(BreadcrumbContext);
  var className = useClassName.useClassName({
    style: styles.BreadcrumbItem,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var children = /*#__PURE__*/React.createElement(React.Fragment, null, React.Children.count(props.children) > 0 ? React.Children.map(props.children, function (child) {
    if (!React.isValidElement(child)) return child;

    if (child.type === BreadcrumbLink) {
      return React.cloneElement(child, __chunk_1._objectSpread2({
        isCurrent: isCurrent
      }, child.props));
    }

    return child;
  }) : props.children, hasSeparator && /*#__PURE__*/React.createElement(BreadcrumbSeparator, null, separator));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: children
  });
}, {
  themeKey: 'Breadcrumb.Item'
});
var BreadcrumbItem = createComponent.createComponent(function (props) {
  var breadcrumbItemProps = useBreadcrumbItemProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: breadcrumbItemProps
  });
}, {
  attach: {
    useProps: useBreadcrumbItemProps
  },
  defaultProps: {
    use: 'li'
  },
  themeKey: 'Breadcrumb.Item'
}); //////////////////////////////

var useBreadcrumbSeparatorProps = createHook.createHook(function (props, _ref3) {
  var themeKey = _ref3.themeKey,
      themeKeyOverride = _ref3.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(BreadcrumbContext);
  var className = useClassName.useClassName({
    style: styles.BreadcrumbSeparator,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    role: 'presentation',
    children: boxProps.children || '/'
  });
}, {
  themeKey: 'Breadcrumb.Separator'
});
var BreadcrumbSeparator = createComponent.createComponent(function (props) {
  var breadcrumbItemProps = useBreadcrumbSeparatorProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: breadcrumbItemProps
  });
}, {
  attach: {
    useProps: useBreadcrumbSeparatorProps
  },
  themeKey: 'Breadcrumb.Separator'
}); //////////////////////////////

var useBreadcrumbLinkProps = createHook.createHook(function (props, _ref4) {
  var themeKey = _ref4.themeKey,
      themeKeyOverride = _ref4.themeKeyOverride;

  var isCurrent = props.isCurrent,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["isCurrent"]);

  var linkProps = isCurrent ? Text.Text.useProps(restProps) : Link.Link.useProps(restProps);
  var contextProps = React.useContext(BreadcrumbContext);
  var className = useClassName.useClassName({
    style: styles.BreadcrumbLink,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: linkProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, linkProps), {}, {
    className: className,
    'aria-current': isCurrent ? 'page' : linkProps['aria-current'],
    href: isCurrent ? undefined : linkProps.href
  });
}, {
  themeKey: 'Breadcrumb.Link'
});
var BreadcrumbLink = createComponent.createComponent(function (props) {
  var breadcrumbItemProps = useBreadcrumbLinkProps(props);
  var use = props.use;

  if (props.isCurrent) {
    use = Text.Text;
  }

  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: use,
    htmlProps: breadcrumbItemProps
  });
}, {
  attach: {
    useProps: useBreadcrumbLinkProps
  },
  defaultProps: {
    use: 'a'
  },
  themeKey: 'Breadcrumb.Link'
});

exports.Breadcrumb = Breadcrumb;
exports.BreadcrumbContext = BreadcrumbContext;
exports.BreadcrumbItem = BreadcrumbItem;
exports.BreadcrumbLink = BreadcrumbLink;
exports.BreadcrumbSeparator = BreadcrumbSeparator;
