'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
var reakit = require('reakit');
var styles = require('./styles-ef2b3fee.js');
var ConditionalWrap = _interopDefault(require('conditional-wrap'));
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-f03a673b.js');
var Flex = require('../Flex/Flex.js');
require('../Icon/styles-5971248c.js');
var Icon = require('../Icon/Icon.js');
require('../Text/styles-778c8fc7.js');
var Text = require('../Text/Text.js');
require('../Spinner/styles-154c4cbf.js');
var Spinner = require('../Spinner/Spinner.js');

var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var disabled = props.disabled,
      focusable = props.focusable,
      iconAfter = props.iconAfter,
      iconAfterProps = props.iconAfterProps,
      iconBefore = props.iconBefore,
      iconBeforeProps = props.iconBeforeProps,
      spinnerProps = props.spinnerProps,
      unstable_clickOnEnter = props.unstable_clickOnEnter,
      unstable_clickOnSpace = props.unstable_clickOnSpace,
      htmlProps = __chunk_1._objectWithoutPropertiesLoose(props, ["disabled", "focusable", "iconAfter", "iconAfterProps", "iconBefore", "iconBeforeProps", "spinnerProps", "unstable_clickOnEnter", "unstable_clickOnSpace"]);

  var buttonProps = reakit.useButton({
    disabled: disabled,
    focusable: focusable,
    unstable_clickOnEnter: unstable_clickOnEnter,
    unstable_clickOnSpace: unstable_clickOnSpace
  }, htmlProps);
  htmlProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, htmlProps), buttonProps));
  var className = useClassName.useClassName({
    style: styles.Button,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: htmlProps.className
  });
  var iconBeforeClassName = useClassName.useClassName({
    style: styles.ButtonIcon,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), {}, {
      isBefore: true
    }),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Icon'
  });
  var iconAfterClassName = useClassName.useClassName({
    style: styles.ButtonIcon,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), {}, {
      isAfter: true
    }),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Icon'
  });
  var spinnerWrapperClassName = useClassName.useClassName({
    style: styles.ButtonSpinnerWrapper,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'SpinnerWrapper'
  });
  var spinnerClassName = useClassName.useClassName({
    style: styles.ButtonSpinner,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Spinner'
  });
  var children = /*#__PURE__*/React.createElement(React.Fragment, null, props.isLoading && /*#__PURE__*/React.createElement(Box.Box, {
    className: spinnerWrapperClassName
  }, /*#__PURE__*/React.createElement(Spinner.Spinner, __chunk_1._extends({
    use: Flex.Flex,
    className: spinnerClassName,
    color: props.variant === 'default' ? props.palette + "Inverted" : props.palette
  }, spinnerProps))), /*#__PURE__*/React.createElement(ConditionalWrap, {
    condition: props.isLoading,
    wrap: function wrap(children) {
      return /*#__PURE__*/React.createElement(Text.Text, null, children);
    }
  }, iconBefore && /*#__PURE__*/React.createElement(Icon.Icon, __chunk_1._extends({
    className: iconBeforeClassName,
    icon: iconBefore
  }, iconBeforeProps)), htmlProps.children, iconAfter && /*#__PURE__*/React.createElement(Icon.Icon, __chunk_1._extends({
    className: iconAfterClassName,
    icon: iconAfter
  }, iconAfterProps))));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, htmlProps), {}, {
    className: className,
    children: children
  });
}, {
  defaultProps: {
    disabled: false,
    iconAfter: undefined,
    iconBefore: undefined,
    isLoading: false,
    isStatic: false,
    variant: 'default',
    palette: 'default',
    size: 'default',
    type: 'button'
  },
  themeKey: 'Button'
});
var Button = createComponent.createComponent(function (props) {
  var buttonProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Button,
    use: props.use,
    htmlProps: buttonProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Button'
  },
  themeKey: 'Button'
});

exports.Button = Button;
