'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
var uniqueId = require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
var reakit = require('reakit');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
var styles = require('./styles-60f2ca0e.js');

var CardContext = React.createContext({});
var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var footer = props.footer,
      headerAddon = props.headerAddon,
      overrides = props.overrides,
      standalone = props.standalone,
      title = props.title,
      variant = props.variant,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["footer", "headerAddon", "overrides", "standalone", "title", "variant"]);

  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2({
    altitude: variant === 'shadowed' ? '100' : null,
    border: variant === 'bordered' ? 'default' : null
  }, restProps));
  var className = useClassName.useClassName({
    style: styles.Card,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var titleId = uniqueId.useUniqueId('cardTitle');
  var descriptionId = uniqueId.useUniqueId('cardDescription');
  var context = React.useMemo(function () {
    return __chunk_1._objectSpread2({
      descriptionId: descriptionId,
      titleId: titleId
    }, props);
  }, [descriptionId, props, titleId]);
  var children = /*#__PURE__*/React.createElement(CardContext.Provider, {
    value: context
  }, standalone ? props.children : /*#__PURE__*/React.createElement(React.Fragment, null, title && /*#__PURE__*/React.createElement(CardHeader, {
    overrides: overrides
  }, /*#__PURE__*/React.createElement(CardTitle, {
    overrides: overrides
  }, title), headerAddon && /*#__PURE__*/React.createElement(Box.Box, null, headerAddon)), /*#__PURE__*/React.createElement(CardContent, {
    overrides: overrides
  }, props.children), footer && /*#__PURE__*/React.createElement(CardFooter, {
    overrides: overrides
  }, footer)));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    'aria-describedby': props.children ? descriptionId : undefined,
    'aria-labelledby': props.title ? titleId : undefined
  }, boxProps), {}, {
    className: className,
    children: children
  });
}, {
  defaultProps: {
    variant: 'shadowed'
  },
  themeKey: 'Card'
});
var Card = createComponent.createComponent(function (props) {
  var cardProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: cardProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Card'
  },
  themeKey: 'Card'
}); /////////////////////////////////////

function CardContent(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(CardContext);
  var cardContentClassName = useClassName.useClassName({
    style: styles.CardContent,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Content'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: cardContentClassName,
    id: context.descriptionId
  }, restProps), children);
} /////////////////////////////////////

function CardTitle(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(CardContext);
  var cardTitleClassName = useClassName.useClassName({
    style: styles.CardTitle,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Title'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: cardTitleClassName,
    id: context.titleId
  }, restProps), children);
} /////////////////////////////////////

function CardHeader(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(CardContext);
  var cardHeaderClassName = useClassName.useClassName({
    style: styles.CardHeader,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Header'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: cardHeaderClassName
  }, restProps), children);
} /////////////////////////////////////

function CardFooter(props) {
  var children = props.children,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children"]);

  var context = React.useContext(CardContext);
  var cardFooterClassName = useClassName.useClassName({
    style: styles.CardFooter,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Footer'
  });
  return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
    className: cardFooterClassName
  }, restProps), children);
}

exports.Card = Card;
exports.CardContent = CardContent;
exports.CardContext = CardContext;
exports.CardFooter = CardFooter;
exports.CardHeader = CardHeader;
exports.CardTitle = CardTitle;
