'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
require('../utils/useClassName.js');
var useBreakpoint = require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
require('../utils/createComponent.js');
require('../utils/createElement.js');
require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('reakit');
require('../Box/styles-efc98bd0.js');
require('../Box/Box.js');
require('../Disclosure/styles-27a9cebb.js');
require('../Disclosure/DisclosureState.js');
require('../Disclosure/Disclosure.js');
require('../Disclosure/DisclosureContent.js');
var index$2 = require('../Disclosure/index.js');
require('../Modal/styles-b6bbf6b0.js');
require('../Modal/ModalState.js');
require('../Modal/ModalBackdrop.js');
require('../Modal/Modal.js');
require('../Modal/ModalDisclosure.js');
require('../Modal/index.js');
require('../Drawer/styles-7978f8ea.js');
require('../Drawer/Drawer.js');
require('../Drawer/DrawerDisclosure.js');
require('../Drawer/DrawerState.js');
var index = require('../Drawer/index.js');
var styles$1 = require('./styles-0dcd922b.js');

var PageContext = React.createContext({
  collapseBelow: 'desktop',
  isCollapsed: false,
  sidebar: {
    isOpen: true,
    open: function open() {
      return undefined;
    },
    close: function close() {
      return undefined;
    },
    toggle: function toggle() {
      return undefined;
    },
    isMinimized: false,
    minimize: function minimize() {
      return undefined;
    },
    maximize: function maximize() {
      return undefined;
    },
    toggleMinimize: function toggleMinimize() {
      return undefined;
    },
    drawer: {},
    disclosure: {}
  },
  header: {
    isOpen: true,
    open: function open() {
      return undefined;
    },
    close: function close() {
      return undefined;
    },
    toggle: function toggle() {
      return undefined;
    },
    disclosure: {}
  }
});
function PageProvider(props) {
  var children = props.children,
      _props$collapseBelow = props.collapseBelow,
      collapseBelow = _props$collapseBelow === void 0 ? 'desktop' : _props$collapseBelow;
  var isCollapsed = useBreakpoint.useBreakpoint("max-" + styles$1.collapseBreakpoints[collapseBelow]);

  var _React$useState = React.useState(false),
      isSidebarMinimized = _React$useState[0],
      setIsSidebarMinimized = _React$useState[1];

  var sidebarDrawer = index.Drawer.useState();
  var sidebarDisclosure = index$2.Disclosure.useState({
    visible: true
  });
  var sidebarState = isCollapsed ? sidebarDrawer : sidebarDisclosure;
  var headerDisclosure = index$2.Disclosure.useState({
    visible: true
  });
  var value = React.useMemo(function () {
    return {
      collapseBelow: collapseBelow,
      isCollapsed: isCollapsed,
      sidebar: {
        isOpen: sidebarState.visible,
        open: sidebarState.show,
        close: sidebarState.hide,
        toggle: sidebarState.toggle,
        isMinimized: isSidebarMinimized,
        minimize: function minimize() {
          return setIsSidebarMinimized(true);
        },
        maximize: function maximize() {
          return setIsSidebarMinimized(false);
        },
        toggleMinimize: function toggleMinimize() {
          return setIsSidebarMinimized(function (isMinimized) {
            return !isMinimized;
          });
        },
        drawer: sidebarDrawer,
        disclosure: sidebarDisclosure
      },
      header: {
        isOpen: headerDisclosure.visible,
        open: headerDisclosure.show,
        close: headerDisclosure.hide,
        toggle: headerDisclosure.toggle,
        disclosure: headerDisclosure
      }
    };
  }, [collapseBelow, headerDisclosure, isCollapsed, isSidebarMinimized, sidebarDisclosure, sidebarDrawer, sidebarState.hide, sidebarState.show, sidebarState.toggle, sidebarState.visible]);
  React.useEffect(function () {
    if (isCollapsed) {
      setIsSidebarMinimized(false);
    }
  }, [isCollapsed]);
  return /*#__PURE__*/React.createElement(PageContext.Provider, {
    value: value
  }, children);
}

exports.PageContext = PageContext;
exports.PageProvider = PageProvider;
