'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('./ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
var useTheme = require('../utils/useTheme.js');
var useLocalStorage = require('../utils/useLocalStorage.js');

var ColorModeContext = React.createContext({
  setColorMode: function setColorMode() {},
  colorMode: 'default'
});
function Provider(props) {
  var children = props.children,
      _defaultMode = props.mode; ////////////////////////////////////

  var _useTheme = useTheme.useTheme(),
      theme = _useTheme.theme;

  var localStorage = useLocalStorage.useLocalStorage();
  var defaultMode = React.useMemo(function () {
    return getDefaultMode(_defaultMode, {
      localStorage: localStorage,
      theme: theme
    });
  }, [_defaultMode, localStorage, theme]); ////////////////////////////////////

  var _React$useState = React.useState(defaultMode),
      mode = _React$useState[0],
      setMode = _React$useState[1]; ////////////////////////////////////


  React.useEffect(function () {
    localStorage.set('colorMode', defaultMode);
  }, [defaultMode, localStorage]); ////////////////////////////////////

  var setColorMode = React.useCallback(function (colorMode) {
    setMode(colorMode);
    localStorage.set('colorMode', colorMode);
  }, [localStorage]); ////////////////////////////////////

  var value = React.useMemo(function () {
    return {
      colorMode: mode,
      setColorMode: setColorMode
    };
  }, [mode, setColorMode]); ////////////////////////////////////

  return /*#__PURE__*/React.createElement(ColorModeContext.Provider, {
    value: value
  }, children);
}

function getDefaultMode(mode, _ref) {
  var localStorage = _ref.localStorage,
      theme = _ref.theme;
  var useSystemColorMode = theme.modes.useSystemColorMode;
  var defaultMode = mode;

  if (useSystemColorMode && typeof window !== 'undefined' && window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches) {
    defaultMode = 'dark';
  }

  if (localStorage.get('colorMode')) {
    defaultMode = localStorage.get('colorMode');
  }

  return defaultMode;
}

exports.ColorModeContext = ColorModeContext;
exports.Provider = Provider;
