'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../utils/getHiddenInputStyles.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-ef2b3fee.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-f03a673b.js');
require('../Flex/Flex.js');
require('../Icon/styles-5971248c.js');
require('../Icon/Icon.js');
require('../Text/styles-778c8fc7.js');
require('../Text/Text.js');
require('../Spinner/styles-154c4cbf.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
require('../Button/index.js');
require('../Set/styles-86e096b6.js');
var _Set = require('../Set/Set.js');
require('../FieldWrapper/styles-822385f1.js');
require('../Card/styles-60f2ca0e.js');
require('../Card/Card.js');
require('../Card/index.js');
require('../Disclosure/styles-27a9cebb.js');
require('../Disclosure/DisclosureState.js');
require('../Disclosure/Disclosure.js');
require('../Disclosure/DisclosureContent.js');
require('../Disclosure/index.js');
require('../Label/styles-bfcde1a2.js');
require('../Label/Label.js');
var FieldWrapper = require('../FieldWrapper/FieldWrapper.js');
var styles = require('./styles-8f7e39bb.js');
var Switch = require('./Switch.js');

var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var defaultValue = props.defaultValue,
      disabled = props.disabled,
      orientation = props.orientation,
      onBlur = props.onBlur,
      onChange = props.onChange,
      options = props.options,
      overrides = props.overrides,
      name = props.name,
      spacing = props.spacing,
      state = props.state,
      value = props.value,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["defaultValue", "disabled", "orientation", "onBlur", "onChange", "options", "overrides", "name", "spacing", "state", "value"]); ////////////////////////////////////////////


  var boxProps = Box.Box.useProps(restProps); ////////////////////////////////////////////

  var className = useClassName.useClassName({
    style: styles.SwitchGroup,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  }); ////////////////////////////////////////////

  var _React$useState = React.useState(defaultValue || []),
      controlledValue = _React$useState[0],
      setControlledValue = _React$useState[1];

  var values = typeof value !== 'undefined' ? value : controlledValue; ////////////////////////////////////////////

  var handleChange = React.useCallback(function (e) {
    var newValue = e.target.value;
    var newValues = [];

    if (values.includes(newValue)) {
      newValues = (values || []).filter(function (val) {
        return val !== newValue;
      });
    } else {
      newValues = [].concat(values || [], [newValue]);
    }

    if (typeof value !== 'undefined') {
      onChange && onChange(newValues, newValue);
    } else {
      setControlledValue(newValues);
    }
  }, [onChange, value, values]);
  var handleBlur = React.useCallback(function () {
    onBlur && onBlur(values);
  }, [onBlur, values]); ////////////////////////////////////////////

  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    role: 'group'
  }, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(_Set.Set, {
      orientation: orientation,
      spacing: spacing
    }, options.map(function (option, i) {
      return /*#__PURE__*/React.createElement(Switch.Switch, __chunk_1._extends({
        key: i
      }, option, {
        // @ts-ignore
        checked: values ? values.includes(option.value) : false,
        onBlur: handleBlur,
        onChange: handleChange,
        overrides: overrides,
        state: state || option.state,
        disabled: disabled || option.disabled
      }));
    }))
  });
}, {
  defaultProps: {
    orientation: 'vertical',
    spacing: 'minor-2'
  },
  themeKey: 'SwitchGroup'
});
var SwitchGroup = createComponent.createComponent(function (props) {
  var textProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: textProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'SwitchGroup'
  },
  themeKey: 'SwitchGroup'
}); ////////////////////////////////////////////////////////////////

var useSwitchGroupFieldProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var defaultChecked = props.defaultChecked,
      description = props.description,
      disabled = props.disabled,
      hint = props.hint,
      orientation = props.orientation,
      isOptional = props.isOptional,
      isRequired = props.isRequired,
      label = props.label,
      name = props.name,
      options = props.options,
      onBlur = props.onBlur,
      onChange = props.onChange,
      overrides = props.overrides,
      switchGroupProps = props.switchGroupProps,
      state = props.state,
      tooltip = props.tooltip,
      tooltipTriggerComponent = props.tooltipTriggerComponent,
      value = props.value,
      validationText = props.validationText,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["defaultChecked", "description", "disabled", "hint", "orientation", "isOptional", "isRequired", "label", "name", "options", "onBlur", "onChange", "overrides", "switchGroupProps", "state", "tooltip", "tooltipTriggerComponent", "value", "validationText"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles.SwitchGroupField,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(FieldWrapper.FieldWrapper, {
      description: description,
      hint: hint,
      isOptional: isOptional,
      isRequired: isRequired,
      label: label,
      labelType: "legend",
      overrides: overrides,
      state: state,
      tooltip: tooltip,
      tooltipTriggerComponent: tooltipTriggerComponent,
      validationText: validationText
    }, function (_ref3) {
      var elementProps = _ref3.elementProps;
      return /*#__PURE__*/React.createElement(SwitchGroup, __chunk_1._extends({
        defaultChecked: defaultChecked,
        disabled: disabled,
        orientation: orientation,
        name: name,
        options: options,
        onBlur: onBlur,
        onChange: onChange,
        overrides: overrides,
        state: state,
        value: value
      }, elementProps, switchGroupProps));
    })
  });
}, {
  themeKey: 'SwitchGroupField'
});
var SwitchGroupField = createComponent.createComponent(function (props) {
  var switchGroupFieldProps = useSwitchGroupFieldProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: switchGroupFieldProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'SwitchGroupField'
  },
  defaultProps: {
    use: 'fieldset'
  },
  themeKey: 'SwitchGroupField'
});

exports.SwitchGroup = SwitchGroup;
exports.SwitchGroupField = SwitchGroupField;
