'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
var useTheme = require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-ef2b3fee.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-f03a673b.js');
require('../Flex/Flex.js');
require('../Icon/styles-5971248c.js');
require('../Icon/Icon.js');
require('../Text/styles-778c8fc7.js');
require('../Text/Text.js');
require('../Spinner/styles-154c4cbf.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
require('../Button/index.js');
require('../Alert/styles-6efb7d2c.js');
require('../Alert/Alert.js');
require('../Alert/index.js');
require('../Modal/styles-b6bbf6b0.js');
require('../Modal/ModalState.js');
require('../Modal/ModalBackdrop.js');
require('../Modal/Modal.js');
require('../Modal/ModalDisclosure.js');
require('../Modal/index.js');
require('../Overlay/styles-00c6c1d9.js');
require('../Overlay/Overlay.js');
require('../Overlay/OverlayDisclosure.js');
require('../Overlay/OverlayState.js');
var index$3 = require('../Overlay/index.js');
require('../Stack/styles-3b5f2587.js');
var Stack = require('../Stack/Stack.js');
var styles$2$1 = require('./styles-4fe5ff95.js');
var Toast = require('./Toast.js');
var ToastContext = require('./ToastContext.js');

var useProps = createHook.createHook(function (props, _ref) {
  var _theme$Toast;

  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var children = props.children,
      isStacked = props.isStacked,
      overlayProps = props.overlayProps,
      spacing = props.spacing,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children", "isStacked", "overlayProps", "spacing"]);

  var _useTheme = useTheme.useTheme(),
      theme = _useTheme.theme;

  var boxProps = Box.Box.useProps(restProps);
  var overlay = index$3.Overlay.useState({
    visible: true,
    animated: true
  });

  var _React$useContext = React.useContext(ToastContext.ToastContext),
      toasts = _React$useContext.toasts;

  var placement = theme === null || theme === void 0 ? void 0 : (_theme$Toast = theme.Toast) === null || _theme$Toast === void 0 ? void 0 : _theme$Toast.placement;
  var className = useClassName.useClassName({
    style: styles$2$1.Toast,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var overlayClassName = useClassName.useClassName({
    style: styles$2$1.ToastOverlay,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), {}, {
      placement: placement
    }),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Overlay'
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(index$3.Overlay, __chunk_1._extends({}, overlay, overlayProps, {
      className: overlayClassName,
      placement: placement
    }), /*#__PURE__*/React.createElement(Stack.Stack, {
      spacing: spacing
    }, toasts.map(function (toast) {
      return /*#__PURE__*/React.createElement(Toast.Toast, __chunk_1._extends({
        key: toast.key
      }, toast), toast.message);
    })))
  });
}, {
  defaultProps: {
    fade: true,
    slide: true,
    spacing: 'major-2'
  },
  themeKey: 'Toast.Manager'
});
var ToastManager = createComponent.createComponent(function (props) {
  var toastManagerProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: toastManagerProps
  });
}, {
  attach: {
    useProps: useProps
  },
  themeKey: 'Toast.Manager'
});

exports.ToastManager = ToastManager;
